from primavera import PrimerSelector, Primer, load_record
import os

# LOAD ALL RECORDS TO ANALYSE AND AVAILABLE PRIMERS
constructs_path = os.path.join("data", "constructs")
records = [
    load_record(os.path.join(constructs_path, f), linear=False)
    for f in sorted(os.listdir(constructs_path))
    if f.endswith(".gb")
]
primers_path = os.path.join("data", "available_primers.fa")
available_primers = Primer.list_from_fasta(primers_path)


# SELECT THE BEST PRIMERS
selector = PrimerSelector(read_range=(150, 800), tm_range=(55, 70))
selected_primers = selector.select_primers(records, available_primers)


# PLOT THE PREDICTED SEQUENCING COVERAGE FOR EACH CONSTRUCT
selector.plot_coverage(
    records=records,
    selected_primers=selected_primers,
    pdf_path="primer_selection_example.pdf",
)


# WRITE ALL PRIMERS IN A CSV FILE (PRIMERS TO ORDER ARE FIRST)
selector.write_primers_table(
    selected_primers=selected_primers, csv_path="primer_selection_example.csv"
)



"""dna_sequencing_viewer/__init__.py"""

# __all__ = []

from .ReadReferenceMatches import (
    ReadReferenceMatches,
    SequencingRead,
    ReadReferenceMatchesSet,
)
from .Primer import Primer
from .SequencingReportGenerator import (
    SequencingReportGenerator,
    PrimersFastaSource,
    PrimersSpreadsheetSource,
    ConstructsFolderSource,
)
from .sequencing_simulation import simulate_sequencing
from .PrimerSelector import PrimerSelector
from .biotools import annotate_record, blast_sequences, load_record
from .version import __version__



import os
import matplotlib

matplotlib.use("Agg")
from primavera import load_record, Primer, PrimerSelector


constructs_path = os.path.join("tests", "data", "constructs")
primers_path = os.path.join("tests", "data", "available_primers.fa")


def test_PrimerSelector(tmpdir):
    records = [
        load_record(os.path.join(constructs_path, f), linear=False)
        for f in sorted(os.listdir(constructs_path))
        if f.endswith(".gb")
    ][:3]
    available_primers = Primer.list_from_fasta(primers_path)

    # SELECT THE BEST PRIMERS
    selector = PrimerSelector(read_range=(150, 800), tm_range=(55, 70))
    selected_primers = selector.select_primers(records, available_primers)

    # WRITE ALL PRIMERS IN A CSV FILE (PRIMERS TO ORDER ARE FIRST)
    csv_path = os.path.join(str(tmpdir), "primer_selection_example.csv")
    table = selector.write_primers_table(
        selected_primers=selected_primers, csv_path=csv_path
    )
    assert table.available.sum() == 2

    selector.write_records_primers_table(
        selected_primers=selected_primers, records=records, csv_path=csv_path
    )

    # PLOT THE PREDICTED SEQUENCING COVERAGE FOR EACH CONSTRUCT
    pdf_path = os.path.join(str(tmpdir), "primer_selection_example.pdf")
    selector.plot_coverage(
        records=records, selected_primers=selected_primers, pdf_path=pdf_path
    )
    selector.write_multifile_report(records, selected_primers, target=str(tmpdir))
    selector.write_multifile_report(
        records, selected_primers, target=os.path.join(str(tmpdir), "a.zip")
    )
